# Democritus Hypothesis

[![PyPI](https://img.shields.io/pypi/v/d8s_hypothesis.svg)](https://pypi.python.org/pypi/d8s_hypothesis)
[![Build Status](https://travis-ci.org/democritus-project/d8s_hypothesis.svg?branch=main)](https://travis-ci.org/democritus-project/d8s_hypothesis)
[![codecov](https://codecov.io/gh/democritus-project/d8s_hypothesis/branch/main/graph/badge.svg)](https://codecov.io/gh/democritus-project/d8s_hypothesis)
[![Documentation Status](https://readthedocs.org/projects/d8s-hypothesis/badge/?version=latest)](http://d8s-hypothesis.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/democritus-project/d8s_hypothesis/shield.svg)](https://pyup.io/repos/github/democritus-project/d8s_hypothesis/)

Democritus functions<sup>[1]</sup> for working with [Hypothesis](https://hypothesis.readthedocs.io/en/latest/).

[1] Democritus functions are <i>simple, effective, modular, well-tested, and well-documented</i> Python functions.

## Usage

Coming soon...

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and Floyd Hightower's [Python project template](https://github.com/fhightower-templates/python-project-template).
